@@ -1,6 +1,6 @@
+use super::bundletool;
 use crate::error::*;
 use std::path::{Path, PathBuf};
-use std::process::Command;
 
 /// ## Extract device-specific APKs from an existing APK set
 ///
@@ -22,7 +22,7 @@ pub struct ExtractApks {
 
 impl ExtractApks {
     /// Specifies the path to the device spec file (from get-device-spec or constructed
-    /// manually) to use for matching.
+    /// manually) to use for matching
     pub fn new(apks: &Path, device_spec: &Path, output_dir: &Path) -> Self {
         Self {
             apks: apks.to_owned(),
@@ -32,7 +32,7 @@ impl ExtractApks {
     }
 
     pub fn run(&self) -> Result<()> {
-        let mut extract_apks = Command::new("extract-apks");
+        let mut extract_apks = bundletool()?;
         extract_apks.arg("--apks");
         extract_apks.arg(&self.apks);
         extract_apks.arg("--device-spec");
